/*
   PostHTTPClient.ino

    based on the IDE Example from 21.11.2016

    noiasca

    Version
    2020-09-26 OK
*/

#include <ESP8266WiFi.h>
#include <ESP8266HTTPClient.h>

#ifndef STASSID
#define STASSID "your-ssid"
#define STAPSK  "your-password"
#endif

//#define SERVER_IP "10.0.1.7:9080" // PC address with emulation on host
//#define SERVER_IP "192.168.1.42"  //

#define SERVER_IP "172.18.67.80"
#define SERVER_RESOURCE "iot/entry.php"  // define the script you want to call 
#define USE_BOARD 0                      // an ID for your board 

const byte pin1 = 0;
const byte pin2 = 2;
const byte pin3 = 14;
const byte adc = A0;

void doWebclient()
{
  if ((WiFi.status() == WL_CONNECTED)) {
    String message;
    WiFiClient client;
    HTTPClient http;
    Serial.print(F("[HTTP] begin\n"));
    // configure traged server and url
    http.begin(client, "http://" SERVER_IP "/" SERVER_RESOURCE);   // MISSING ... in configuration?
    http.addHeader("Content-Type", "application/x-www-form-urlencoded"); // // standard content type for simple form-posts, for more see https://en.wikipedia.org/wiki/Media_type
    // build your post data
    message = "board=";
    message += USE_BOARD;
    message += "&uptime=";
    message += millis()/1000;
    message += "&adc=";
    message += analogRead(adc);
    message += "&pin1=";
    message += digitalRead(pin1);
    message += "&pin2=";
    message += digitalRead(pin2);
    // start connection and send HTTP header and body
    int httpCode = http.POST(message);
    // httpCode will be negative on error
    if (httpCode > 0) {
      // HTTP header has been send and Server response header has been handled
      Serial.printf("[HTTP] POST code: %d\n", httpCode);
      if (httpCode == HTTP_CODE_OK) {                  // file found at server
        const String& payload = http.getString();
        Serial.println(F("received payload:\n<<"));
        Serial.println(payload);
        Serial.println(F(">>"));
      }
    } else {
      Serial.printf("[HTTP] POST failed, error: %s\n", http.errorToString(httpCode).c_str());
    }
    http.end();
  }
  else
  {
    Serial.println("[HTTP] not connected");
  }
}

void timerWebclient()
{
  const uint16_t interval = 60 * 1000UL;           // set the interval for your webclient to post data
  static uint32_t previousMillis = - interval;
  uint32_t currentMillis = millis();
  if (currentMillis - previousMillis > interval)
  {
    doWebclient();
    previousMillis = currentMillis;
  }
}

void setup() {
  Serial.begin(115200);
  Serial.print  (F("\n\nESP8266 POST HTTP webclient\nBoard "));
  Serial.println(USE_BOARD);
  pinMode(adc, INPUT);
  pinMode(pin1, INPUT);
  pinMode(pin2, INPUT);
  WiFi.begin(STASSID, STAPSK);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.print(F("\nConnected! IP address: "));
  Serial.println(WiFi.localIP());
}

void loop() {
  timerWebclient();                   // call the timer for the webclient
  // do other things in your loop
}
